@@ -1,4 +1,4 @@
-//@line 38 "/usr/obj/ports/firefox35-3.5.8/mozilla-1.9.1/toolkit/content/inlineSpellCheckUI.js"
+//@line 38 "/usr/obj/i386/firefox35-3.5.11/mozilla-1.9.1/toolkit/content/inlineSpellCheckUI.js"
 
 var InlineSpellCheckerUI = {
   mOverMisspelling: false,
@@ -186,6 +186,7 @@ var InlineSpellCheckerUI = {
 
       this.mDictionaryNames.push(list[i]);
       var item = document.createElement("menuitem");
+      item.setAttribute("id", "spell-check-dictionary-" + list[i]);
       item.setAttribute("label", displayName);
       item.setAttribute("type", "checkbox");
       this.mDictionaryItems.push(item);
